"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@salesforce/core");
const command_1 = require("@salesforce/command");
const ToolbeltCommand_1 = require("./ToolbeltCommand");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('salesforce-alm', 'reporterCommand');
/**
 * Support --resultfomat on commands. Useful for commands that can output different
 * formats like human, csv, json, or different testing results like tap, etc.
 */
class ReporterCommand extends ToolbeltCommand_1.ToolbeltCommand {
    static get flags() {
        if (!this.flagsConfig) {
            this.flagsConfig = {};
        }
        this.flagsConfig.resultformat = command_1.flags.enum(Object.assign({
            char: 'r',
            description: messages.getMessage('ResultFormatDescription'),
            longDescription: messages.getMessage('ResultFormatLongDescription'),
            options: ['human', 'csv', 'json']
        }, this.resultFormatOptions));
        return super.flags;
    }
    // Override the init to set this.json if the --resultformat (reporter) flag is json
    async init() {
        try {
            const { flags } = this.parse({
                flags: this.statics.flags,
                args: this.statics.args
            });
            // Set json if the reporter is json
            if (flags.resultformat === 'json' && !flags.json) {
                this.argv.push('--json');
            }
        }
        catch (err) {
            /* parse can throw, so let super.init handle those */
        }
        return super.init();
    }
    // TypeScript does not yet have assertion-free polymorphic access to a class's static side from the instance side
    get statics() {
        return this.constructor;
    }
}
ReporterCommand.resultFormatOptions = {};
exports.ReporterCommand = ReporterCommand;

//# sourceMappingURL=ReporterCommand.js.map
