"use strict";
/**
 * Org Preferences are exposed through different APIs
 * Singleton object encapsulating registry of supported Org Preference types
 */
// P R I V A T E
// pref APIs
const AccountSettingsApi = 'accountSettings';
const ActivitiesSettingsApi = 'activitiesSettings';
const ContractSettingsApi = 'contractSettings';
const EntitlementSettingsApi = 'entitlementSettings';
const ForecastingSettingsApi = 'forecastingSettings';
const IdeasSettingsApi = 'ideasSettings';
const KnowledgeSettingsApi = 'knowledgeSettings';
const LiveAgentSettingsApi = 'liveAgentSettings';
const NameSettingsApi = 'nameSettings';
const OpportunitySettingsApi = 'opportunitySettings';
const OrderSettingsApi = 'orderSettings';
const ProductSettingsApi = 'productSettings';
const QuoteSettingsApi = 'quoteSettings';
const SearchSettingsApi = 'searchSettings';
const OrganizationSettingsDetailApi = 'orgPreferenceSettings';
// supported org preferences and the API through which they are set
const orgPreferenceApiMap = new Map([
    ['IsAccountTeamsEnabled', AccountSettingsApi],
    ['ShowViewHierarchyLink', AccountSettingsApi],
    ['IsActivityRemindersEnabled', ActivitiesSettingsApi],
    ['IsDragAndDropSchedulingEnabled', ActivitiesSettingsApi],
    ['IsEmailTrackingEnabled', ActivitiesSettingsApi],
    ['IsGroupTasksEnabled', ActivitiesSettingsApi],
    ['IsMultidayEventsEnabled', ActivitiesSettingsApi],
    ['IsRecurringEventsEnabled', ActivitiesSettingsApi],
    ['IsRecurringTasksEnabled', ActivitiesSettingsApi],
    ['IsSidebarCalendarShortcutEnabled', ActivitiesSettingsApi],
    ['IsSimpleTaskCreateUIEnabled', ActivitiesSettingsApi],
    ['ShowEventDetailsMultiUserCalendar', ActivitiesSettingsApi],
    ['ShowHomePageHoverLinksForEvents', ActivitiesSettingsApi],
    ['ShowMyTasksHoverLinks', ActivitiesSettingsApi],
    ['ShowRequestedMeetingsOnHomePage', ActivitiesSettingsApi],
    ['AutoCalculateEndDate', ContractSettingsApi],
    ['IsContractHistoryTrackingEnabled', ContractSettingsApi],
    ['NotifyOwnersOnContractExpiration', ContractSettingsApi],
    ['AssetLookupLimitedToActiveEntitlementsOnAccount', EntitlementSettingsApi],
    ['AssetLookupLimitedToActiveEntitlementsOnContact', EntitlementSettingsApi],
    ['AssetLookupLimitedToSameAccount', EntitlementSettingsApi],
    ['AssetLookupLimitedToSameContact', EntitlementSettingsApi],
    ['IsEntitlementsEnabled', EntitlementSettingsApi],
    ['EntitlementLookupLimitedToActiveStatus', EntitlementSettingsApi],
    ['EntitlementLookupLimitedToSameAccount', EntitlementSettingsApi],
    ['EntitlementLookupLimitedToSameAsset', EntitlementSettingsApi],
    ['EntitlementLookupLimitedToSameContact', EntitlementSettingsApi],
    ['IsForecastsEnabled', ForecastingSettingsApi],
    ['IsChatterProfileEnabled', IdeasSettingsApi],
    ['IsIdeaThemesEnabled', IdeasSettingsApi],
    ['IsIdeasEnabled', IdeasSettingsApi],
    ['IsIdeasReputationEnabled', IdeasSettingsApi],
    ['IsCreateEditOnArticlesTabEnabled', KnowledgeSettingsApi],
    ['IsExternalMediaContentEnabled', KnowledgeSettingsApi],
    ['IsKnowledgeEnabled', KnowledgeSettingsApi],
    ['ShowArticleSummariesCustomerPortal', KnowledgeSettingsApi],
    ['ShowArticleSummariesInternalApp', KnowledgeSettingsApi],
    ['ShowArticleSummariesPartnerPortal', KnowledgeSettingsApi],
    ['ShowValidationStatusField', KnowledgeSettingsApi],
    ['IsLiveAgentEnabled', LiveAgentSettingsApi],
    ['IsMiddleNameEnabled', NameSettingsApi],
    ['IsNameSuffixEnabled', NameSettingsApi],
    ['IsOpportunityTeamEnabled', OpportunitySettingsApi],
    ['IsOrdersEnabled', OrderSettingsApi],
    ['IsNegativeQuantityEnabled', OrderSettingsApi],
    ['IsReductionOrdersEnabled', OrderSettingsApi],
    ['IsCascadeActivateToRelatedPricesEnabled', ProductSettingsApi],
    ['IsQuantityScheduleEnabled', ProductSettingsApi],
    ['IsRevenueScheduleEnabled', ProductSettingsApi],
    ['IsQuoteEnabled', QuoteSettingsApi],
    ['DocumentContentSearchEnabled', SearchSettingsApi],
    ['OptimizeSearchForCjkEnabled', SearchSettingsApi],
    ['RecentlyViewedUsersForBlankLookupEnabled', SearchSettingsApi],
    ['SidebarAutoCompleteEnabled', SearchSettingsApi],
    ['SidebarDropDownListEnabled', SearchSettingsApi],
    ['SidebarLimitToItemsIownCheckboxEnabled', SearchSettingsApi],
    ['SingleSearchResultShortcutEnabled', SearchSettingsApi],
    ['SpellCorrectKnowledgeSearchEnabled', SearchSettingsApi],
    ['AnalyticsSharingEnable', OrganizationSettingsDetailApi],
    ['DisableParallelApexTesting', OrganizationSettingsDetailApi],
    ['EnhancedEmailEnabled', OrganizationSettingsDetailApi],
    ['EventLogWaveIntegEnabled', OrganizationSettingsDetailApi],
    ['SendThroughGmailPref', OrganizationSettingsDetailApi],
    ['Translation', OrganizationSettingsDetailApi],
    ['S1OfflinePref', OrganizationSettingsDetailApi],
    ['S1EncryptedStoragePref2', OrganizationSettingsDetailApi],
    ['OfflineDraftsEnabled', OrganizationSettingsDetailApi],
    ['AsyncSaveEnabled', OrganizationSettingsDetailApi],
    ['ChatterEnabled', OrganizationSettingsDetailApi],
    ['SelfSetPasswordInApi', OrganizationSettingsDetailApi],
    ['SocialProfilesEnable', OrganizationSettingsDetailApi],
    ['PathAssistantsEnabled', OrganizationSettingsDetailApi],
    ['LoginForensicsEnabled', OrganizationSettingsDetailApi],
    ['S1DesktopEnabled', OrganizationSettingsDetailApi],
    ['NetworksEnabled', OrganizationSettingsDetailApi],
    ['NotesReservedPref01', OrganizationSettingsDetailApi],
    ['CompileOnDeploy', OrganizationSettingsDetailApi],
    ['VoiceEnabled', OrganizationSettingsDetailApi],
    ['TerritoryManagement2Enable', OrganizationSettingsDetailApi],
    ['ApexApprovalLockUnlock', OrganizationSettingsDetailApi]
]);
const orgPreferenceMdMap = new Map([
    ['IsAccountTeamsEnabled', 'enableAccountTeams'],
    ['ShowViewHierarchyLink', 'showViewHierarchyLink'],
    ['IsActivityRemindersEnabled', 'enableActivityReminders'],
    ['IsDragAndDropSchedulingEnabled', 'enableDragAndDropScheduling'],
    ['IsEmailTrackingEnabled', 'enableEmailTracking'],
    ['IsGroupTasksEnabled', 'enableGroupTasks'],
    ['IsMultidayEventsEnabled', 'enableMultidayEvents'],
    ['IsRecurringEventsEnabled', 'enableRecurringEvents'],
    ['IsRecurringTasksEnabled', 'enableRecurringTasks'],
    ['IsSidebarCalendarShortcutEnabled', 'enableSidebarCalendarShortcut'],
    ['IsSimpleTaskCreateUIEnabled', 'enableSimpleTaskCreateUI'],
    ['ShowEventDetailsMultiUserCalendar', 'showEventDetailsMultiUserCalendar'],
    ['ShowHomePageHoverLinksForEvents', 'showHomePageHoverLinksForEvents'],
    ['ShowMyTasksHoverLinks', 'showMyTasksHoverLinks'],
    ['ShowRequestedMeetingsOnHomePage', 'showRequestedMeetingsOnHomePage'],
    ['AutoCalculateEndDate', 'autoCalculateEndDate'],
    ['IsContractHistoryTrackingEnabled', 'enableContractHistoryTracking'],
    ['NotifyOwnersOnContractExpiration', 'notifyOwnersOnContractExpiration'],
    ['AssetLookupLimitedToActiveEntitlementsOnAccount', 'assetLookupLimitedToActiveEntitlementsOnAccount'],
    ['AssetLookupLimitedToActiveEntitlementsOnContact', 'assetLookupLimitedToActiveEntitlementsOnContact'],
    ['AssetLookupLimitedToSameAccount', 'assetLookupLimitedToSameAccount'],
    ['AssetLookupLimitedToSameContact', 'assetLookupLimitedToSameContact'],
    ['IsEntitlementsEnabled', 'enableEntitlements'],
    ['EntitlementLookupLimitedToActiveStatus', 'entitlementLookupLimitedToActiveStatus'],
    ['EntitlementLookupLimitedToSameAccount', 'entitlementLookupLimitedToSameAccount'],
    ['EntitlementLookupLimitedToSameAsset', 'entitlementLookupLimitedToSameAsset'],
    ['EntitlementLookupLimitedToSameContact', 'entitlementLookupLimitedToSameContact'],
    ['IsForecastsEnabled', 'enableForecasts'],
    ['IsChatterProfileEnabled', 'enableChatterProfile'],
    ['IsIdeaThemesEnabled', 'enableIdeaThemes'],
    ['IsIdeasEnabled', 'enableIdeas'],
    ['IsIdeasReputationEnabled', 'enableIdeasReputation'],
    ['IsCreateEditOnArticlesTabEnabled', 'enableCreateEditOnArticlesTab'],
    ['IsExternalMediaContentEnabled', 'enableExternalMediaContent'],
    ['IsKnowledgeEnabled', 'enableKnowledge'],
    ['ShowArticleSummariesCustomerPortal', 'showArticleSummariesCustomerPortal'],
    ['ShowArticleSummariesInternalApp', 'showArticleSummariesInternalApp'],
    ['ShowArticleSummariesPartnerPortal', 'showArticleSummariesPartnerPortal'],
    ['ShowValidationStatusField', 'showValidationStatusField'],
    ['IsLiveAgentEnabled', 'enableLiveAgent'],
    ['IsMiddleNameEnabled', 'enableMiddleName'],
    ['IsNameSuffixEnabled', 'enableNameSuffix'],
    ['IsOpportunityTeamEnabled', 'enableOpportunityTeam'],
    ['IsOrdersEnabled', 'enableOrders'],
    ['IsNegativeQuantityEnabled', 'enableNegativeQuantity'],
    ['IsReductionOrdersEnabled', 'enableReductionOrders'],
    ['IsCascadeActivateToRelatedPricesEnabled', 'enableCascadeActivateToRelatedPrices'],
    ['IsQuantityScheduleEnabled', 'enableQuantitySchedule'],
    ['IsRevenueScheduleEnabled', 'enableRevenueSchedule'],
    ['IsQuoteEnabled', 'enableQuote'],
    ['DocumentContentSearchEnabled', 'documentContentSearchEnabled'],
    ['OptimizeSearchForCjkEnabled', 'optimizeSearchForCJKEnabled'],
    ['RecentlyViewedUsersForBlankLookupEnabled', 'recentlyViewedUsersForBlankLookupEnabled'],
    ['SidebarAutoCompleteEnabled', 'sidebarAutoCompleteEnabled'],
    ['SidebarDropDownListEnabled', 'sidebarDropDownListEnabled'],
    ['SidebarLimitToItemsIownCheckboxEnabled', 'sidebarLimitToItemsIOwnCheckboxEnabled'],
    ['SingleSearchResultShortcutEnabled', 'singleSearchResultShortcutEnabled'],
    ['SpellCorrectKnowledgeSearchEnabled', 'spellCorrectKnowledgeSearchEnabled'],
    ['AnalyticsSharingEnable', 'analyticsSharingEnable'],
    ['DisableParallelApexTesting', 'disableParallelApexTesting'],
    ['EnhancedEmailEnabled', 'enhancedEmailEnabled'],
    ['EventLogWaveIntegEnabled', 'eventLogWaveIntegEnabled'],
    ['SendThroughGmailPref', 'sendThroughGmailPref'],
    ['Translation', 'translation'],
    ['S1OfflinePref', 's1OfflinePref'],
    ['S1EncryptedStoragePref2', 's1EncryptedStoragePref2'],
    ['OfflineDraftsEnabled', 'offlineDraftsEnabled'],
    ['AsyncSaveEnabled', 'asyncSaveEnabled'],
    ['ChatterEnabled', 'chatterEnabled'],
    ['SelfSetPasswordInApi', 'selfSetPasswordInApi'],
    ['SocialProfilesEnable', 'socialProfilesEnable'],
    ['PathAssistantsEnabled', 'pathAssistantsEnabled'],
    ['LoginForensicsEnabled', 'loginForensicsEnabled'],
    ['S1DesktopEnabled', 's1DesktopEnabled'],
    ['NetworksEnabled', 'networksEnabled'],
    ['NotesReservedPref01', 'notesReservedPref01'],
    ['CompileOnDeploy', 'compileOnDeploy'],
    ['VoiceEnabled', 'voiceEnabled'],
    ['TerritoryManagement2Enable', 'territoryManagement2Enable'],
    ['ApexApprovalLockUnlock', 'apexApprovalLockUnlock']
]);
module.exports = {
    ACCOUNT_SETTINGS_API: AccountSettingsApi,
    ACTIVITIES_SETTINGS_API: ActivitiesSettingsApi,
    CONTRACT_SETTINGS_API: ContractSettingsApi,
    ENTITLEMENT_SETTINGS_API: EntitlementSettingsApi,
    FORECASTING_SETTINGS_API: ForecastingSettingsApi,
    IDEAS_SETTINGS_API: IdeasSettingsApi,
    KNOWLEDGE_SETTINGS_API: KnowledgeSettingsApi,
    LIVE_AGENT_SETTINGS_API: LiveAgentSettingsApi,
    NAME_SETTINGS_API: NameSettingsApi,
    OPPORTUNITY_SETTINGS_API: OpportunitySettingsApi,
    ORDER_SETTINGS_API: OrderSettingsApi,
    PRODUCT_SETTINGS_API: ProductSettingsApi,
    QUOTE_SETTINGS_API: QuoteSettingsApi,
    SEARCH_SETTINGS_API: SearchSettingsApi,
    ORGANIZATION_SETTINGS_DETAIL_API: OrganizationSettingsDetailApi,
    /**
     * Takes in an org preference name and returns the API through which it is set
     * @param prefName The org preference name
     * @returns the API name for the org preference
     */
    whichApi(prefName) {
        return orgPreferenceApiMap.get(prefName);
    },
    /**
     * Takes in an org preference name and returns the MD-API name
     * @param prefName The org preference name
     * @returns the MDAPI name for the org preference
     */
    forMdApi(prefName) {
        return orgPreferenceMdMap.get(prefName);
    },
    /**
     * Convenience method for testing to get Org Preference Map
     * @returns the Org Preference Map
     */
    allPrefsMap() {
        return orgPreferenceApiMap;
    }
};

//# sourceMappingURL=orgPrefRegistry.js.map
